@@ -372,7 +372,7 @@ cube_view <- function(view, extent, srs, nx, ny, nt, dx, dy, dt, aggregation, re
   
   
   # 
-  xx = libgdalcubes_create_view(xx)
+  xx = gc_create_view(xx)
   
   class(xx) <- c("cube_view", class(xx))
   return(xx)
