@@ -32,7 +32,7 @@ std::shared_ptr<chunk_data> filter_pixel_cube::read_chunk(chunkid_t id) {
     GCBS_TRACE("filter_pixel_cube::read_chunk(" + std::to_string(id) + ")");
 
     if (id >= count_chunks())
-        return std::shared_ptr<chunk_data>();  // chunk is outside of the view, we don't need to read anything.
+        return  std::make_shared<chunk_data>();  // chunk is outside of the view, we don't need to read anything.
 
     std::shared_ptr<chunk_data> out = std::make_shared<chunk_data>();
     std::shared_ptr<chunk_data> in = _in_cube->read_chunk(id);
@@ -93,6 +93,10 @@ std::shared_ptr<chunk_data> filter_pixel_cube::read_chunk(chunkid_t id) {
     for (uint16_t i = 0; i < _in_cube->bands().count(); ++i) {  // only free name of actual variables (not functions)
         delete[] vars[i].name;
     }
+    // check if chunk is completely NAN and if yes, return empty chunk
+    if (out->all_nan()) {
+        out = std::make_shared<chunk_data>();
+    }
 
     return out;
 }
