@@ -12,6 +12,12 @@ std::shared_ptr<chunk_data> stream_apply_pixel_cube::read_chunk(chunkid_t id) {
     if (id >= count_chunks())
         return out;  // chunk is outside of the view, we don't need to read anything.
 
+
+    std::shared_ptr<chunk_data> inbuf = _in_cube->read_chunk(id);
+    // check whether input chunk is empty and if yes, avoid computations
+    if (inbuf->empty()) {
+        return out;
+    }
     coords_nd<uint32_t, 3> size_tyx = chunk_size(id);
     coords_nd<uint32_t, 4> size_btyx = {_bands.count(), size_tyx[0], size_tyx[1], size_tyx[2]};
     out->size(size_btyx);
@@ -27,9 +33,9 @@ std::shared_ptr<chunk_data> stream_apply_pixel_cube::read_chunk(chunkid_t id) {
 
     // generate in and out filename
     std::string f_in = filesystem::join(config::instance()->get_streaming_dir(),
-                                        utils::generate_unique_filename(12, ".stream_", "_in"));
+                                        utils::generate_unique_filename(12, ".stream_" + std::to_string(id) + "_", "_in"));
     std::string f_out = filesystem::join(config::instance()->get_streaming_dir(),
-                                         utils::generate_unique_filename(12, ".stream_", "_out"));
+                                         utils::generate_unique_filename(12, ".stream_" + std::to_string(id) + "_", "_out"));
 
     std::string errstr;  // capture error string
 
@@ -76,35 +82,29 @@ std::shared_ptr<chunk_data> stream_apply_pixel_cube::read_chunk(chunkid_t id) {
     int str_size = proj.size();
     f_in_stream.write((char *)(&str_size), sizeof(int));
     f_in_stream.write(proj.c_str(), sizeof(char) * str_size);
-    std::shared_ptr<chunk_data> inbuf = _in_cube->read_chunk(id);
     f_in_stream.write(((char *)(inbuf->buf())), sizeof(double) * inbuf->size()[0] * inbuf->size()[1] * inbuf->size()[2] * inbuf->size()[3]);
     f_in_stream.close();
 
     /* setenv / _putenv is not thread-safe, we need to get a mutex until the child process has been started. */
     static std::mutex mtx;
+    utils::env::instance().set({
+        {"GDALCUBES_STREAMING", "1"},
+        {"GDALCUBES_STREAMING_CHUNK_ID", std::to_string(id)},
+        {"GDALCUBES_STREAMING_FILE_IN", f_in},
+        {"GDALCUBES_STREAMING_FILE_OUT", f_out}});
     mtx.lock();
-#ifdef _WIN32
-    _putenv("GDALCUBES_STREAMING=1");
-    //_putenv((std::string("GDALCUBES_STREAMING_DIR") + "=" + config::instance()->get_streaming_dir().c_str()).c_str());
-    _putenv((std::string("GDALCUBES_STREAMING_CHUNK_ID") + "=" + std::to_string(id)).c_str());
-    _putenv((std::string("GDALCUBES_STREAMING_FILE_IN") + "=" + f_in.c_str()).c_str());
-    _putenv((std::string("GDALCUBES_STREAMING_FILE_OUT") + "=" + f_out.c_str()).c_str());
-#else
-    setenv("GDALCUBES_STREAMING", "1", 1);
-    // setenv("GDALCUBES_STREAMING_DIR", config::instance()->get_streaming_dir().c_str(), 1);
-    setenv("GDALCUBES_STREAMING_CHUNK_ID", std::to_string(id).c_str(), 1);
-    setenv("GDALCUBES_STREAMING_FILE_IN", f_in.c_str(), 1);
-    setenv("GDALCUBES_STREAMING_FILE_OUT", f_out.c_str(), 1);
-#endif
 
     // start process
+    TinyProcessLib::Config pconf;
+    pconf.show_window = TinyProcessLib::Config::ShowWindow::hide;
     TinyProcessLib::Process process(
         _cmd, "", [](const char *bytes, std::size_t n) {},
         [&errstr](const char *bytes, std::size_t n) {
-            errstr = std::string(bytes, n);
-            GCBS_DEBUG(errstr);
+            std::string s(bytes, n);
+            errstr = errstr + s;
         },
-        false);
+        false, pconf);
+    utils::env::instance().unset_all();
     mtx.unlock();
     auto exit_status = process.get_exit_status();
     filesystem::remove(f_in);
@@ -117,6 +117,7 @@ std::shared_ptr<chunk_data> stream_apply_pixel_cube::read_chunk(chunkid_t id) {
         throw std::string("ERROR in stream_apply_pixel_cube::read_chunk(): external program returned exit code " +
                           std::to_string(exit_status));
     }
+    GCBS_DEBUG(errstr);
 
     // read output data
     std::ifstream f_out_stream(f_out, std::ios::in | std::ios::binary);
